//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[allExtraYaku](all-extra-yaku.md)

# allExtraYaku

[common]\
val [allExtraYaku](all-extra-yaku.md): [Set](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)&lt;[Yaku](../-yaku/index.md)&gt;

所有额外役种（与手牌无关的役种）
